Scriptname AR_QuickLoot_Ref_AliasScript extends ReferenceAlias  

Actor Property PlayerRef Auto

GlobalVariable Property AR_DeadNPC Auto
GlobalVariable Property AR_DeadAnimals Auto
GlobalVariable Property AR_Doors Auto

FormList Property AR_Interact_CustomDeadAnimals Auto
FormList Property AR_Interact_CustomDeadNPCs Auto
FormList Property AR_Interact_CustomContainers Auto
FormList Property AR_Interact_Barrels Auto
FormList Property AR_Interact_MissiveBoard Auto

MagicEffect Property ForwardMGEF Auto

Race Property DLC1VampireBeastRace Auto
Race Property WerewolfBeastRace Auto

AR_QuestScript Property arQuestScript Auto

Bool isBusy

Event OnInit()
	RegisterForMenu("LootMenu")
EndEvent

Event OnPlayerLoadGame()
	RegisterForMenu("LootMenu")
EndEvent

Event OnMenuOpen(String menuName)
	If menuName == "LootMenu"
		If !PlayerRef.IsWeaponDrawn() && !PlayerRef.GetSitState() && !PlayerRef.IsSwimming() && !PlayerRef.IsOnMount() && !PlayerRef.GetAnimationVariableBool("isStaggering") && PlayerRef.GetRace() != DLC1VampireBeastRace  && PlayerRef.GetRace() != WerewolfBeastRace
			GoToState("QuickLootingST")
		EndIf
	EndIf
EndEvent

Event OnMenuClose(String menuName)
	If menuName == "LootMenu"
		GoToState("")
	EndIf
EndEvent

State QuickLootingST
	Event OnItemAdded(Form akBaseItem, int aiItemCount, ObjectReference akItemReference, ObjectReference akSourceContainer)
		If (arQuestScript.AR_NoFirstPerson.GetValue() == 1 && Game.GetCameraState() == 0) || (isBusy || !UI.IsMenuOpen("LootMenu")) || (akSourceContainer != Game.GetCurrentCrosshairRef() && !AR_Interact_CustomContainers.HasForm(Game.GetCurrentCrosshairRef().GetBaseObject())) || PlayerRef.IsWeaponDrawn()
			; Doesn't play animation if no first person is enabled, during an animation, QuickLoot is not opened anymore, if the source container of the item is different than the one player is currently looking at or with weapons drawn.
			Return
		EndIf
		; Looting Animals
		If AR_DeadAnimals.GetValue() && !AR_Interact_CustomContainers.HasForm(Game.GetCurrentCrosshairRef().GetBaseObject()) && (akSourceContainer.HasKeywordString("ActorTypeAnimal") || AR_Interact_CustomDeadAnimals.HasForm(akSourceContainer.GetBaseObject())) 
			isBusy = True
			arQuestScript.IsPlayerIn3rd()
			arQuestScript.AR_DogUp.SetValue(7)
			Utility.Wait(0.1)
			Debug.SendanimationEvent(PlayerRef, "AO_Tan")
			Utility.Wait(1.5)
			While UI.IsMenuOpen("LootMenu") && !PlayerRef.HasMagicEffect(ForwardMGEF)
				Utility.Wait(0.1)
			EndWhile
			Debug.SendAnimationEvent(PlayerRef, "IdleSilentBow")
			Utility.Wait(0.5)
			arQuestScript.AR_DogUp.SetValue(0)
			Debug.SendanimationEvent(PlayerRef, "IdleForceDefaultState")
			arQuestScript.Returnto1st()
			isBusy = False
		; Looting NPCs
		ElseIf AR_DeadNPC.GetValue() && (akSourceContainer.HasKeywordString("ActorTypeNPC") || akSourceContainer.HasKeywordString("ActorTypeDwarven") || akSourceContainer.HasKeywordString("ActorTypeCreature") || AR_Interact_CustomDeadNPCs.HasForm(akSourceContainer.GetBaseObject()) || AR_Interact_CustomContainers.HasForm(Game.GetCurrentCrosshairRef().GetBaseObject()))
			; Support for Immersive Hunting Animations
			If akSourceContainer.HasKeywordString("ActorTypeAnimal") || akSourceContainer.HasKeywordString("LootingSmallAnimal") || akSourceContainer.HasKeywordString("LootingLargeAnimal") 
				Return
			EndIf
			isBusy = True
			arQuestScript.IsPlayerIn3rd()
			If PlayerRef.IsSneaking()
				arQuestScript.AR_DogUp.SetValue(3)
				Utility.Wait(0.1)
				PlayerRef.PlayIdle(arQuestScript.idleSearchingChest)
				Utility.Wait(0.1)
				arQuestScript.AR_DogUp.SetValue(0)
			Else
				PlayerRef.PlayIdle(arQuestScript.idleSearchBody)
			EndIf
			Utility.Wait(0.8)
			While UI.IsMenuOpen("LootMenu") && !PlayerRef.HasMagicEffect(ForwardMGEF)
				Utility.Wait(0.1)
			EndWhile
			PlayerRef.PlayIdle(arQuestScript.IdleStop_Loose)
			arQuestScript.Returnto1st()
			isBusy = False
		; Looting chests, wardrobes or custom containers
		ElseIf AR_Doors.GetValue() && (akSourceContainer.GetBaseObject() as Container || AR_Interact_CustomContainers.HasForm(akSourceContainer.GetBaseObject()))
			isBusy = True
			If AR_Interact_MissiveBoard.HasForm(akSourceContainer.GetBaseObject())
				arQuestScript.IsPlayerIn3rd()
				PlayerRef.Playidle(arQuestScript.IdleStudy)
				Utility.Wait(0.5)
				akSourceContainer.Activate(PlayerRef)
				Utility.Wait(0.3)
				While UI.IsMenuOpen("LootMenu") && !PlayerRef.HasMagicEffect(ForwardMGEF)
					Utility.Wait(0.1)
				EndWhile
				PlayerRef.PlayIdle(arQuestScript.IdleStop_Loose)
				arQuestScript.Returnto1st()
			ElseIf arQuestScript.AR_SlowChest.GetValue() 
				arQuestScript.IsPlayerIn3rd()
				Utility.Wait(0.1)
				Float fPlayerObjectPosition = (akSourceContainer.GetPositionZ() - PlayerRef.GetPositionZ()) / 100
				If PlayerRef.IsSneaking()
					If fPlayerObjectPosition > 0.45 || AR_Interact_Barrels.HasForm(akSourceContainer.GetBaseObject())
						arQuestScript.AR_DogUp.SetValue(4)
					ElseIf fPlayerObjectPosition < 0.25
						arQuestScript.AR_DogUp.SetValue(3)
					EndIf
					Utility.Wait(0.1)
					PlayerRef.PlayIdle(arQuestScript.idleSearchingChest)
				ElseIf fPlayerObjectPosition > 0.40 || AR_Interact_Barrels.HasForm(akSourceContainer.GetBaseObject())
					arQuestScript.AR_DogUp.SetValue(3)
					PlayerRef.PlayIdle(arQuestScript.idleSearchingTable)
				Else
					arQuestScript.AR_DogUp.SetValue(3)
					PlayerRef.PlayIdle(arQuestScript.idleSearchBody)
				EndIf
				Utility.Wait(0.8)
				While UI.IsMenuOpen("LootMenu") && !PlayerRef.HasMagicEffect(ForwardMGEF)
					Utility.Wait(0.1)
				EndWhile
				arQuestScript.AR_DogUp.SetValue(0)
				PlayerRef.PlayIdle(arQuestScript.IdleStop_Loose)
				arQuestScript.Returnto1st()
			Else ; Realistic container animations is disabled, plays the "Open door" animation.
				Debug.SendanimationEvent(PlayerRef, "AO_OpenDoor") 
				Utility.wait(0.4)
				Debug.SendAnimationEvent(PlayerRef, "OffsetStop")
				Utility.wait(0.2)
			EndIf
			isBusy = False
		EndIf	
	EndEvent
EndState

